package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.AppletUsers;

/**
 * 用户Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-30
 */
public interface AppletUsersMapper 
{
    /**
     * 查询用户
     * 
     * @param userId 用户主键
     * @return 用户
     */
    public AppletUsers selectAppletUsersByUserId(Long userId);

    /**
     * 查询用户列表
     * 
     * @param appletUsers 用户
     * @return 用户集合
     */
    public List<AppletUsers> selectAppletUsersList(AppletUsers appletUsers);

    /**
     * 新增用户
     * 
     * @param appletUsers 用户
     * @return 结果
     */
    public int insertAppletUsers(AppletUsers appletUsers);

    /**
     * 修改用户
     * 
     * @param appletUsers 用户
     * @return 结果
     */
    public int updateAppletUsers(AppletUsers appletUsers);

    /**
     * 删除用户
     * 
     * @param userId 用户主键
     * @return 结果
     */
    public int deleteAppletUsersByUserId(Long userId);

    /**
     * 批量删除用户
     * 
     * @param userIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppletUsersByUserIds(Long[] userIds);
}
