package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletUsers;
import com.ruoyi.model.service.IAppletUsersService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户Controller
 * 
 * @author ruoyi
 * @date 2025-03-30
 */
@RestController
@RequestMapping("/model/AppletUsers")
public class AppletUsersController extends BaseController
{
    @Autowired
    private IAppletUsersService appletUsersService;

    /**
     * 查询用户列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletUsers:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletUsers appletUsers)
    {
        startPage();
        List<AppletUsers> list = appletUsersService.selectAppletUsersList(appletUsers);
        return getDataTable(list);
    }

    /**
     * 导出用户列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletUsers:export')")
    @Log(title = "用户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletUsers appletUsers) throws IOException {
        List<AppletUsers> list = appletUsersService.selectAppletUsersList(appletUsers);
        ExcelUtil<AppletUsers> util = new ExcelUtil<AppletUsers>(AppletUsers.class);
        util.exportExcel(response, list, "用户数据");
    }

    /**
     * 获取用户详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletUsers:query')")
    @GetMapping(value = "/{userId}")
    public AjaxResult getInfo(@PathVariable("userId") Long userId)
    {
        return success(appletUsersService.selectAppletUsersByUserId(userId));
    }

    /**
     * 新增用户
     */
    @PreAuthorize("@ss.hasPermi('model:AppletUsers:add')")
    @Log(title = "用户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletUsers appletUsers)
    {
        return toAjax(appletUsersService.insertAppletUsers(appletUsers));
    }

    /**
     * 修改用户
     */
    @PreAuthorize("@ss.hasPermi('model:AppletUsers:edit')")
    @Log(title = "用户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletUsers appletUsers)
    {
        return toAjax(appletUsersService.updateAppletUsers(appletUsers));
    }

    /**
     * 删除用户
     */
    @PreAuthorize("@ss.hasPermi('model:AppletUsers:remove')")
    @Log(title = "用户", businessType = BusinessType.DELETE)
	@DeleteMapping("/{userIds}")
    public AjaxResult remove(@PathVariable Long[] userIds)
    {
        return toAjax(appletUsersService.deleteAppletUsersByUserIds(userIds));
    }
}
